==> element-ui-2.0.0-rc.1.jar: META-INF/resources/webjars/element-ui/2.0.0-rc.1/lib/umd/locale/pl.js <==
(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/pl', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.pl = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'OK',
        clear: 'Wyczyść'
      },
      datepicker: {
        now: 'Teraz',
        today: 'Dzisiaj',
        cancel: 'Anuluj',
        clear: 'Wyczyść',
        confirm: 'OK',
        selectDate: 'Wybierz datę',
        selectTime: 'Wybierz godzinę',
        startDate: 'Data początkowa',
        startTime: 'Godzina początkowa',
        endDate: 'Data końcowa',
        endTime: 'Czas końcowa',
        year: 'rok',
        month1: 'styczeń',
        month2: 'luty',
        month3: 'marzec',
        month4: 'kwiecień',
        month5: 'maj',
        month6: 'czerwiec',
        month7: 'lipiec',
        month8: 'sierpień',
        month9: 'wrzesień',
        month10: 'październik',
        month11: 'listopad',
        month12: 'grudzień',
        week: 'tydzień',
        weeks: {
          sun: 'niedz.',
          mon: 'pon.',
          tue: 'wt.',
          wed: 'śr.',
          thu: 'czw.',
          fri: 'pt.',
          sat: 'sob.'
        },
        months: {
          jan: 'STY',
          feb: 'LUT',
          mar: 'MAR',
          apr: 'KWI',
          may: 'MAJ',
          jun: 'CZE',
          jul: 'LIP',
          aug: 'SIE',
          sep: 'WRZ',
          oct: 'PAŹ',
          nov: 'LIS',
          dec: 'GRU'
        }
      },
      select: {
        loading: 'Ładowanie',
        noMatch: 'Brak dopasowań',
        noData: 'Brak danych',
        placeholder: 'Wybierz'
      },
      cascader: {
        noMatch: 'Brak dopasowań',
        loading: 'Ładowanie',
        placeholder: 'Wybierz'
      },
      pagination: {
        goto: 'Idź do',
        pagesize: '/strona',
        total: 'Wszystkich {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'Wiadomość',
        confirm: 'OK',
        cancel: 'Anuluj',
        error: 'Wiadomość zawiera niedozwolone znaki'
      },
      upload: {
        deleteTip: 'press delete to remove', // to be translated
        delete: 'Kasuj',
        preview: 'Podgląd',
        continue: 'Kontynuuj'
      },
      table: {
        emptyText: 'Brak danych',
        confirmFilter: 'Potwierdź',
        resetFilter: 'Resetuj',
        clearFilter: 'Wszystko',
        sumText: 'Sum' // to be translated
      },
      tree: {
        emptyText: 'Brak danych'
      },
      transfer: {
        noMatch: 'Brak dopasowań',
        noData: 'Brak danych',
        titles: ['List 1', 'List 2'], // to be translated
        filterPlaceholder: 'Enter keyword', // to be translated
        noCheckedFormat: '{total} items', // to be translated
        hasCheckedFormat: '{checked}/{total} checked' // to be translated
      }
    }
  };
  module.exports = exports['default'];
});

==> element-ui-2.0.4.jar: META-INF/resources/webjars/element-ui/2.0.4/lib/umd/locale/pl.js <==
(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/pl', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.pl = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'OK',
        clear: 'Wyczyść'
      },
      datepicker: {
        now: 'Teraz',
        today: 'Dzisiaj',
        cancel: 'Anuluj',
        clear: 'Wyczyść',
        confirm: 'OK',
        selectDate: 'Wybierz datę',
        selectTime: 'Wybierz godzinę',
        startDate: 'Data początkowa',
        startTime: 'Godzina początkowa',
        endDate: 'Data końcowa',
        endTime: 'Czas końcowa',
        prevYear: 'Previous Year', // to be translated
        nextYear: 'Next Year', // to be translated
        prevMonth: 'Previous Month', // to be translated
        nextMonth: 'Next Month', // to be translated
        year: 'rok',
        month1: 'styczeń',
        month2: 'luty',
        month3: 'marzec',
        month4: 'kwiecień',
        month5: 'maj',
        month6: 'czerwiec',
        month7: 'lipiec',
        month8: 'sierpień',
        month9: 'wrzesień',
        month10: 'październik',
        month11: 'listopad',
        month12: 'grudzień',
        week: 'tydzień',
        weeks: {
          sun: 'niedz.',
          mon: 'pon.',
          tue: 'wt.',
          wed: 'śr.',
          thu: 'czw.',
          fri: 'pt.',
          sat: 'sob.'
        },
        months: {
          jan: 'STY',
          feb: 'LUT',
          mar: 'MAR',
          apr: 'KWI',
          may: 'MAJ',
          jun: 'CZE',
          jul: 'LIP',
          aug: 'SIE',
          sep: 'WRZ',
          oct: 'PAŹ',
          nov: 'LIS',
          dec: 'GRU'
        }
      },
      select: {
        loading: 'Ładowanie',
        noMatch: 'Brak dopasowań',
        noData: 'Brak danych',
        placeholder: 'Wybierz'
      },
      cascader: {
        noMatch: 'Brak dopasowań',
        loading: 'Ładowanie',
        placeholder: 'Wybierz'
      },
      pagination: {
        goto: 'Idź do',
        pagesize: '/strona',
        total: 'Wszystkich {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'Wiadomość',
        confirm: 'OK',
        cancel: 'Anuluj',
        error: 'Wiadomość zawiera niedozwolone znaki'
      },
      upload: {
        deleteTip: 'press delete to remove', // to be translated
        delete: 'Kasuj',
        preview: 'Podgląd',
        continue: 'Kontynuuj'
      },
      table: {
        emptyText: 'Brak danych',
        confirmFilter: 'Potwierdź',
        resetFilter: 'Resetuj',
        clearFilter: 'Wszystko',
        sumText: 'Sum' // to be translated
      },
      tree: {
        emptyText: 'Brak danych'
      },
      transfer: {
        noMatch: 'Brak dopasowań',
        noData: 'Brak danych',
        titles: ['List 1', 'List 2'], // to be translated
        filterPlaceholder: 'Enter keyword', // to be translated
        noCheckedFormat: '{total} items', // to be translated
        hasCheckedFormat: '{checked}/{total} checked' // to be translated
      }
    }
  };
  module.exports = exports['default'];
});
